==> kubernetes-model-core-5.7.4-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeClaimStatusFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface PersistentVolumeClaimStatusFluent<A extends io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToAccessModes(java.lang.Integer index,java.lang.String item);
  public A setToAccessModes(java.lang.Integer index,java.lang.String item);
  public A addToAccessModes(java.lang.String... items);
  public A addAllToAccessModes(java.util.Collection<java.lang.String> items);
  public A removeFromAccessModes(java.lang.String... items);
  public A removeAllFromAccessModes(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getAccessModes();
  public java.lang.String getAccessMode(java.lang.Integer index);
  public java.lang.String getFirstAccessMode();
  public java.lang.String getLastAccessMode();
  public java.lang.String getMatchingAccessMode(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingAccessMode(java.util.function.Predicate<java.lang.String> predicate);
  public A withAccessModes(java.util.List<java.lang.String> accessModes);
  public A withAccessModes(java.lang.String... accessModes);
  public java.lang.Boolean hasAccessModes();
  public A addNewAccessMode(java.lang.String arg0);
  public A addToCapacity(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value);
  public A addToCapacity(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map);
  public A removeFromCapacity(java.lang.String key);
  public A removeFromCapacity(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map);
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getCapacity();
  public <K,V>A withCapacity(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> capacity);
  public java.lang.Boolean hasCapacity();
  public A addToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.PersistentVolumeClaimConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition> getConditions();
  public java.util.List<io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition> buildConditions();
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition buildCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition buildFirstCondition();
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition buildLastCondition();
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.PersistentVolumeClaimConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.PersistentVolumeClaimConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition... conditions);
  public java.lang.Boolean hasConditions();
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition item);
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition item);
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.PersistentVolumeClaimConditionBuilder> predicate);
  public java.lang.String getPhase();
  public A withPhase(java.lang.String phase);
  public java.lang.Boolean hasPhase();
  
  /**
   * Method is deprecated. use withPhase instead.
   */
  @java.lang.Deprecated
  public A withNewPhase(java.lang.String arg0);
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.PersistentVolumeClaimConditionFluent<io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> kubernetes-model-core-5.11.0-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeClaimStatusFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface PersistentVolumeClaimStatusFluent<A extends io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToAccessModes(java.lang.Integer index,java.lang.String item);
  public A setToAccessModes(java.lang.Integer index,java.lang.String item);
  public A addToAccessModes(java.lang.String... items);
  public A addAllToAccessModes(java.util.Collection<java.lang.String> items);
  public A removeFromAccessModes(java.lang.String... items);
  public A removeAllFromAccessModes(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getAccessModes();
  public java.lang.String getAccessMode(java.lang.Integer index);
  public java.lang.String getFirstAccessMode();
  public java.lang.String getLastAccessMode();
  public java.lang.String getMatchingAccessMode(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingAccessMode(java.util.function.Predicate<java.lang.String> predicate);
  public A withAccessModes(java.util.List<java.lang.String> accessModes);
  public A withAccessModes(java.lang.String... accessModes);
  public java.lang.Boolean hasAccessModes();
  public A addNewAccessMode(java.lang.String arg0);
  public A addToCapacity(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value);
  public A addToCapacity(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map);
  public A removeFromCapacity(java.lang.String key);
  public A removeFromCapacity(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map);
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getCapacity();
  public <K,V>A withCapacity(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> capacity);
  public java.lang.Boolean hasCapacity();
  public A addToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.PersistentVolumeClaimConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition> getConditions();
  public java.util.List<io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition> buildConditions();
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition buildCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition buildFirstCondition();
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition buildLastCondition();
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.PersistentVolumeClaimConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.PersistentVolumeClaimConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition... conditions);
  public java.lang.Boolean hasConditions();
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition item);
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.PersistentVolumeClaimCondition item);
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.PersistentVolumeClaimConditionBuilder> predicate);
  public java.lang.String getPhase();
  public A withPhase(java.lang.String phase);
  public java.lang.Boolean hasPhase();
  
  /**
   * Method is deprecated. use withPhase instead.
   */
  @java.lang.Deprecated
  public A withNewPhase(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.PersistentVolumeClaimConditionFluent<io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
